@@ -12,34 +12,35 @@ class Command(BaseCommand):
     """
     Command class.
     """
-    option_list = BaseCommand.option_list + (
-        make_option('--applabel',dest='app_label',help='The app label to which the local model belongs.'),
-        make_option('--localmodel',dest='local_mod',help='The name of the local model'),
-        make_option('--localid',dest='local_id',help='The id of the local model'),
-    )
     
     def handle(self,*args,**options):
         """
         Handler method.
         """
-        if not len(args) == 1:
-            raise CommandError('Must specify content key as arg.')
+        if not len(args) == 2:
+            raise CommandError('Usage: add_content_record <content-key> <app-label>.<model>:<model-id>')
         
         content_key = args[0]
+        app_label, compound_id = args[1].split('.')
+        local_model, local_id = compound_id.split(':')
+        
         print 'content key is',content_key
-        print 'options are:',options
+        print 'app label is',app_label
+        print 'local model is',local_model
+        print 'local is is',local_id
+       
         content_type = None
         try:
-            content_type = ContentType.objects.get(app_label=options['app_label'],model=options['local_mod'])
+            content_type = ContentType.objects.get(app_label=app_label,model=local_model)
         except ContentType.DoesNotExist:
             raise CommandError('No such local content type.')
         
         local_mod = content_type.model_class()
         if not hasattr(local_mod,'ACE'):
-            raise CommandError('Local model %s is not configured to be linked to ACE.' % options['local_mod'])
+            raise CommandError('Local model %s is not configured to be linked to ACE.' % local_model)
         
         AxilentContentRecord.objects.create(local_content_type=content_type,
-                                            local_id=options['local_id'],
+                                            local_id=local_id,
                                             axilent_content_type=local_mod.ACE.content_type,
                                             axilent_content_key=content_key)
         
